@@ -83,6 +83,7 @@ sub gst_service_sysv_get_paths
        "debian-3.0"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "debian-3.1"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "debian-4.0"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "debian-5.0"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "debian-testing" => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-5.04"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-5.10"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
@@ -162,6 +163,7 @@ sub gst_service_sysv_get_runlevels
        "debian-3.0"     => [2, 3],
        "debian-3.1"     => [2, 3],
        "debian-4.0"     => [2, 3],
+       "debian-5.0"     => [2, 3],
        "debian-testing" => [2, 3],
        "ubuntu-5.04"    => [2, 3],
        "ubuntu-5.10"    => [2, 3],
@@ -240,6 +242,7 @@ sub gst_service_get_runlevel_roles
      "debian-3.0"     => "debian-2.2",
      "debian-3.1"     => "debian-2.2",
      "debian-4.0"     => "debian-2.2",
+     "debian-5.0"     => "debian-2.2",
      "debian-testing" => "debian-2.2",
      "ubuntu-5.04"    => "debian-2.2",
      "ubuntu-5.10"    => "debian-2.2",
@@ -1721,6 +1724,7 @@ sub gst_service_get_status
        "debian-3.0"   => \&gst_service_debian_get_status,
        "debian-3.1"   => \&gst_service_debian_get_status,
        "debian-4.0"   => \&gst_service_debian_get_status,
+       "debian-5.0"   => \&gst_service_debian_get_status,
        "debian-testing" => \&gst_service_debian_get_status,
        "ubuntu-5.04"  => \&gst_service_debian_get_status,
        "ubuntu-5.10"  => \&gst_service_debian_get_status,
